import request from '@/utils/request'
// 新增角色
export function roleAdd(data) {
	return request({
		url: '/system/dataRole',
		method: 'post',
		data
	})
}
//查询角色
export function roleList(params) {
	return request({
		url: '/system/dataRole/list',
		method: 'get',
		params
	})
}
//修改角色
export function roleUpd(data) {
	return request({
		url: '/system/dataRole',
		method: 'put',
		data
	})
}
//删除角色
export function roleDel(data) {
	return request({
		url: '/system/dataRole/' + data,
		method: 'delete'
	})
}
//禁用角色
export function roleStatus(data) {
	return request({
		url: '/system/dataRole/changeStatus',
		method: 'put',
		data
	})
}
//获取角色的权限信息
export function authList(params) {
	return request({
		url: '/system/dataRole/' + params,
		method: 'get'
	})
}
//修改角色的权限信息
export function authUpd(data) {
	return request({
		url: '/system/dataRole/changeDept',
		method: 'put',
		data
	})
}
//获取部门树
export function deptList() {
	return request({
		url: '/system/dept/treeselect',
		method: 'get'
	})
}
